@@ -4,6 +4,8 @@ from pwdgen.password import Password
 from pwdgen import PasswordGenerator as PGen
 
 from argparse import ArgumentParser
+from termcolor import colored
+from pathlib import Path
 
 parser = ArgumentParser(description="Learn passwords!")
 parser.add_argument("--new", action="store_true", dest="create_new")
@@ -15,6 +17,7 @@ parser.add_argument("-l", "--length", dest="length", default=16)
 
 
 if __name__ == "__main__":
+    Path("~/.pwdlearner").mkdir(parents=True, exist_ok=True)
     args = parser.parse_args()
 
     if not args.create_new:
@@ -24,11 +27,16 @@ if __name__ == "__main__":
             print("Please, specify tag --new to create a new password.")
             exit(1)
     else:
-        gen = PGen(
-            args.length,
-            allowed_chars=args.allowed_chars,
-            exclude_ambigous_chars=args.exclude_ambigous_chars,
-        )
+        try:
+            gen = PGen(
+                int(args.length),
+                allowed_chars=args.allowed_chars,
+                exclude_ambigous_chars=args.exclude_ambigous_chars,
+            )
+        except ValueError as e:
+            print(colored(e, "red"))
+            exit(1)
+
         pwd = gen.generate()
 
     pwd.learn()
